@@ -218,15 +218,23 @@ const char *ScriptChecks::chkThrow(Line *line, ScriptImage *img)
 	return NULL;
 }
 
-const char *ScriptChecks::chkLabel(Line *line, ScriptImage *img)
+const char *ScriptChecks::chkGoto(Line *line, ScriptImage *img)
 {
-	if(getMember(line))
-		return "member not used in this command";
+	unsigned opt = 0;
 
-	return chkGoto(line, img);
+	if(getMember(line))
+		return "goto has no member";
+
+	if(!getOption(line, &opt))
+		return "goto label missing";
+
+	if(getOption(line, &opt))
+		return "only one goto label";
+
+	return NULL;
 }
 
-const char *ScriptChecks::chkGoto(Line *line, ScriptImage *img)
+const char *ScriptChecks::chkLabel(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
 
@@ -412,6 +420,17 @@ const char *ScriptChecks::chkExpr(Line *line, ScriptImage *img)
 	return chkExpression(line, img);
 }
 
+const char *ScriptChecks::chkChar(Line *line, ScriptImage *img)
+{
+	if(getMember(line))
+		return "char always size 1";
+
+	if(hasKeywords(line))
+		return "no keywords used in char";
+
+	return chkAllVars(line, img);
+}
+
 const char *ScriptChecks::chkString(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
@@ -425,16 +444,31 @@ const char *ScriptChecks::chkString(Line *line, ScriptImage *img)
 	return chkAllVars(line, img);
 }
 
+const char *ScriptChecks::chkVarType(Line *line, ScriptImage *img)
+{  
+	if(getMember(line))
+		return "no members in type";
+
+	if(hasKeywords(line))
+		return "no keywords in type";
+
+	return chkAllVars(line, img);
+}
+	
 const char *ScriptChecks::chkVar(Line *line, ScriptImage *img)    
 {
         const char *cp = getMember(line);
 
         if(cp && !isdigit(cp[1]))
+	{
                 cp = chkProperty(line, img);
+		if(!cp)
+			return "property invalid for var";
+	}
         else
                 cp = NULL;
 
-        if(!useKeywords(line, "=size"))
+        if(!useKeywords(line, "=size=value"))
                 return "invalid keyword used";
 
         return chkAllVars(line, img);
@@ -540,12 +574,12 @@ const char *ScriptChecks::chkType(Line *line, ScriptImage *img)
 const char *ScriptChecks::chkFirstVar(Line *line, ScriptImage *img)
 {
 	const char *cp;
+	unsigned idx = 0;
 
-	if(line->argc < 2)
+	cp = getOption(line, &idx);
+	if(!cp)
 		return "too few arguments";
 
-	cp = line->args[0];
-
 	if(*cp != '%' && *cp != '@' && *cp != '&')
 		return "first argument must be symbol";
 
