@@ -103,6 +103,10 @@ void ScriptCompiler::fastBranch(ScriptInterp *interp)
 	}
 }
 
+bool ScriptCompiler::checkSegment(Name *scr)
+{
+	return true;
+}
 
 const char *ScriptCompiler::preproc(const char *token)
 {
@@ -580,10 +584,7 @@ int ScriptCompiler::compile(istream *str, char *name, const char *scrname)
 
 	gvarname[0] = '%';
 	
-	if(bm)
-		snprintf(gvarname + 1, 56, "mac.%s.", name);
-	else
-		snprintf(gvarname + 1, 56, "scr.%s.", name);
+	snprintf(gvarname + 1, 56, "%s.", name);
 
 	gvarlen = strlen(gvarname);
 
@@ -607,12 +608,16 @@ compile:
 
 	setString(csname, sizeof(csname), name);
 	cp = strstr(csname, "::");
-	if(cp && !stricmp(cp, "::main"))
+
+	if(cp && !stricmp(cp, "::main") && !ripple)
 	{
 		initkey = SCRIPT_INDEX_SIZE;
 		*cp = 0;
 	}
 
+	if(ripple && cp)
+		initkey = SCRIPT_INDEX_SIZE; 
+
         key = Script::getIndex(csname);
 
 	if(first && bm)
@@ -648,6 +653,8 @@ compile:
 			script->access = scrPROTECTED;
 		else if(!strnicmp(pmode, "fun", 3))
 			script->access = scrFUNCTION;
+		else if(!stricmp(pmode, "local"))
+			script->access = scrLOCAL;
 		else
 			script->access = access;
 	}
@@ -700,6 +707,8 @@ compile:
 				{
 					wrapper = false;
 					embed = NULL;
+					if(ripple && !strchr(name, ':'))
+						break;
 					setString(buffer, 16, exit_token);
 				}
 				else
@@ -789,8 +798,8 @@ first:
 
 			if(!ripple && !embed && !apps)
   			  if(!stricmp(token, "private") || !stricmp(token,
-"protected") || !stricmp(token, "public") || !stricmp(token, "program")
-|| !stricmp(token, "state") || !stricmp(token, "module"))
+"protected") || !stricmp(token, "public") || !stricmp(token, "program") ||
+!stricmp(token, "module"))
 			{
 				if(!stricmp(token, "module"))
 				{
@@ -822,14 +831,6 @@ repname1:
 				break;
 			}
 
-
-			if(!stricmp(token, "service") && !ripple && !embed && !apps)
-			{
-				ftoken = "options";
-				pmode = "public";
-				goto repname1;
-			}
-
 			if(!strnicmp(token, "func", 4) && !ripple && !embed && !apps && !strchr(token, ':'))
 			{
 				ftoken = "fconst";
@@ -837,6 +838,22 @@ repname1:
 				goto repname1;
 			}
 
+
+                        if(!stricmp(token, "macro") && !ripple && !embed && !apps && !strchr(token, ':'))
+                        {
+                                ftoken = "fconst";
+                                pmode = "function";
+                                goto repname1;
+                        }
+                             
+
+                        if(!stricmp(token, "local") && !ripple && !embed && !apps && !strchr(token, ':'))
+                        {
+                                ftoken = "fconst";
+                                pmode = "local";
+                                goto repname1;
+                        }
+                             
 			if(!strnicmp(token, "proc", 4) && !ripple && !embed && !apps && !strchr(token, ':'))
 			{
 				pmode = "function";
@@ -1137,7 +1154,10 @@ noexec:
 					token = "";
 			}
 			else if(token[0] == 0x01)
-				token = alloc(++token);
+			{
+				token[0]='{';
+				token = alloc(token);
+			}
 			else if(token[0] == '.' && isalpha(token[1]))
 			{
 				cp = token + strlen(token) - 1;
@@ -1302,6 +1322,8 @@ noexec:
 	}
 	total += count;
 
+	checkSegment(script);
+
 	if(first && count)
 		initcount = count;
 	else if(count)
