@@ -120,12 +120,18 @@ ScriptCommand()
 			(Check)&ScriptChecks::chkNumber},
 		{"expr", false, (Method)&ScriptMethods::scrExpr,
 			(Check)&ScriptChecks::chkExpr},
+		{"var", true, (Method)&ScriptMethods::scrVar,
+			(Check)&ScriptChecks::chkVar},
+		{"type", true, (Method)&ScriptMethods::scrType,
+			(Check)&ScriptChecks::chkVarType},
+                {"vartype", true, (Method)&ScriptMethods::scrType,
+                        (Check)&ScriptChecks::chkVarType},  
 		{"string", true, (Method)&ScriptMethods::scrVar,
 			(Check)&ScriptChecks::chkString}, 
                 {"str", true, (Method)&ScriptMethods::scrVar,     
                         (Check)&ScriptChecks::chkString},
 		{"char", true, (Method)&ScriptMethods::scrVar,
-			(Check)&ScriptChecks::chkVar},
+			(Check)&ScriptChecks::chkChar},
 		{"signal", false, (Method)&ScriptMethods::scrSignal,
 			(Check)&ScriptChecks::chkSignal},
 		{"throw", false, (Method)&ScriptMethods::scrThrow,
@@ -137,7 +143,7 @@ ScriptCommand()
 		{"gosub", false, (Method)&ScriptMethods::scrCall,
 			(Check)&ScriptChecks::chkCall},
 		{"source", false, (Method)&ScriptMethods::scrCall,
-			(Check)&ScriptChecks::chkGoto},
+			(Check)&ScriptChecks::chkLabel},
 		{"return", false, (Method)&ScriptMethods::scrReturn,
 			(Check)&ScriptChecks::chkReturn},
 		{"restart", false, (Method)&ScriptMethods::scrRestart,
@@ -164,6 +170,8 @@ ScriptCommand()
 			(Check)&ScriptChecks::chkArray},
 		{"init", true, (Method)&ScriptMethods::scrSet,
 			(Check)&ScriptChecks::chkSet},
+		{"pset", true, (Method)&ScriptMethods::scrSet,
+			(Check)&ScriptChecks::chkSet},
 		{"set", true, (Method)&ScriptMethods::scrSet,
 			(Check)&ScriptChecks::chkSet},
 		{"add", true, (Method)&ScriptMethods::scrSet,
