@@ -106,7 +106,8 @@ public:
 		scrPUBLIC,
 		scrPROTECTED,
 		scrPRIVATE,
-		scrFUNCTION
+		scrFUNCTION,
+		scrLOCAL
 	};
 
 	typedef enum scrAccess scrAccess;
@@ -284,6 +285,9 @@ public:
         static void addFunction(const char *name, unsigned count, Function i);
         static void addConditional(const char *name, Cond test);
 
+	static bool isPrivate(Name *scr);
+	static bool isFunction(Name *scr);
+
 protected:        
         static Test *test;
         static Fun *ifun;
@@ -765,12 +769,16 @@ public:
 
 	const char *chkVar(Line *line, ScriptImage *img);
 
+	const char *chkVarType(Line *line, ScriptImage *img);
+
 	const char *chkDecimal(Line *line, ScriptImage *img);
 
 	const char *chkNumber(Line *line, ScriptImage *img);
 
 	const char *chkString(Line *line, ScriptImage *img);
 
+	const char *chkChar(Line *line, ScriptImage *img);
+
 	const char *chkExpr(Line *line, ScriptImage *img);
 
 	const char *chkIndex(Line *line, ScriptImage *img);
@@ -1091,6 +1099,8 @@ protected:
 	
 	friend class __EXPORT ScriptInterp;
 
+	virtual bool checkSegment(Name *scr);
+
 public:
 	char *getToken(char **pre = NULL);
 
@@ -1203,7 +1213,16 @@ public:
 		unsigned decimal : 4;
 		unsigned base : 8;
 	};
-
+	
+        static long getRealValue(double val, unsigned prec);
+        static double getDouble(long value, unsigned prec);
+        static long getInteger(long value, unsigned prec);
+        static long getTens(unsigned prec);
+        long getIntValue(const char *text, unsigned prec, ScriptProperty *property = NULL);
+        int numericExpression(long *list, int max, unsigned prec, ScriptProperty *property = NULL);
+	bool conditionalExpression(void);
+	bool conditional(void);
+	
 protected:
 	Mutex *lock;	// any additional lock that is siezed
 	ScriptCommand *cmd;
@@ -1463,20 +1482,12 @@ public:
 class __EXPORT ScriptMethods : public ScriptInterp
 {
 public:
-        static long getRealValue(double val, unsigned prec);
-        static double getDouble(long value, unsigned prec);
-        static long getInteger(long value, unsigned prec);
-        static long getTens(unsigned prec);
-        long getIntValue(const char *text, unsigned prec, ScriptProperty *property = NULL);
-        int numericExpression(long *list, int max, unsigned prec, ScriptProperty *property = NULL);
-	bool conditionalExpression(void);
-	bool conditional(void);
-
 	bool scrNop(void);
 	bool scrError(void);
 	bool scrExit(void);
 	bool scrDecimal(void);
 	bool scrVar(void);
+	bool scrType(void);
 	bool scrNumber(void);
 	bool scrSlog(void);
 	bool scrExpr(void);
@@ -1485,6 +1496,7 @@ public:
 	bool scrRef(void);
 	bool scrRestart(void);
 	bool scrInit(void);
+	bool intGoto(void);
 	bool scrGoto(void);
 	bool scrCall(void);
 	bool scrReturn(void);
